@@ -2,7 +2,7 @@ import React from 'react';
 import { mount } from 'enzyme';
 import Graph from './Graph';
 import Chart from '../Chart';
-import { GraphSeriesXY, FieldType, ArrayVector, dateTime, FieldColorMode } from '@grafana/data';
+import { GraphSeriesXY, FieldType, ArrayVector, dateTime, FieldColorModeId } from '@grafana/data';
 
 const series: GraphSeriesXY[] = [
   {
@@ -25,7 +25,7 @@ const series: GraphSeriesXY[] = [
       type: FieldType.number,
       name: 'a-series',
       values: new ArrayVector([10, 20, 10]),
-      config: { color: { mode: FieldColorMode.Fixed, fixedColor: 'red' } },
+      config: { color: { mode: FieldColorModeId.Fixed, fixedColor: 'red' } },
     },
     timeStep: 3600000,
     yAxis: {
@@ -52,7 +52,7 @@ const series: GraphSeriesXY[] = [
       type: FieldType.number,
       name: 'b-series',
       values: new ArrayVector([20, 30, 40]),
-      config: { color: { mode: FieldColorMode.Fixed, fixedColor: 'blue' } },
+      config: { color: { mode: FieldColorModeId.Fixed, fixedColor: 'blue' } },
     },
     timeStep: 3600000,
     yAxis: {
